@@ -42,10 +42,12 @@
 
 /* Format version bounds for layout */
 const unsigned H5O_layout_ver_bounds[] = {
-    H5O_LAYOUT_VERSION_1,                      /* H5F_LIBVER_EARLIEST */
-    H5O_LAYOUT_VERSION_3, /* H5F_LIBVER_V18 */ /* H5O_LAYOUT_VERSION_DEFAULT */
-    H5O_LAYOUT_VERSION_4,                      /* H5F_LIBVER_V110 */
-    H5O_LAYOUT_VERSION_LATEST                  /* H5F_LIBVER_LATEST */
+    H5O_LAYOUT_VERSION_1, /* H5F_LIBVER_EARLIEST */
+    H5O_LAYOUT_VERSION_3,
+    /* H5F_LIBVER_V18 */      /* H5O_LAYOUT_VERSION_DEFAULT */
+    H5O_LAYOUT_VERSION_4,     /* H5F_LIBVER_V110 */
+    H5O_LAYOUT_VERSION_4,     /* H5F_LIBVER_V112 */
+    H5O_LAYOUT_VERSION_LATEST /* H5F_LIBVER_LATEST */
 };
 
 /*****************************/
@@ -64,9 +66,6 @@ const unsigned H5O_layout_ver_bounds[] = {
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              Thursday, March 20, 2008
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -77,7 +76,7 @@ H5D__layout_set_io_ops(const H5D_t *dataset)
     FUNC_ENTER_PACKAGE
 
     /* check args */
-    HDassert(dataset);
+    assert(dataset);
 
     /* Set the I/O functions for each layout type */
     switch (dataset->shared->layout.type) {
@@ -119,8 +118,8 @@ H5D__layout_set_io_ops(const H5D_t *dataset)
 
                 case H5D_CHUNK_IDX_NTYPES:
                 default:
-                    HDassert(0 && "Unknown chunk index method!");
-                    HGOTO_ERROR(H5E_DATASET, H5E_UNSUPPORTED, FAIL, "unknown chunk index method")
+                    assert(0 && "Unknown chunk index method!");
+                    HGOTO_ERROR(H5E_DATASET, H5E_UNSUPPORTED, FAIL, "unknown chunk index method");
             } /* end switch */
             break;
 
@@ -135,8 +134,8 @@ H5D__layout_set_io_ops(const H5D_t *dataset)
         case H5D_LAYOUT_ERROR:
         case H5D_NLAYOUTS:
         default:
-            HGOTO_ERROR(H5E_DATASET, H5E_UNSUPPORTED, FAIL, "unknown storage method")
-    } /* end switch */ /*lint !e788 All appropriate cases are covered */
+            HGOTO_ERROR(H5E_DATASET, H5E_UNSUPPORTED, FAIL, "unknown storage method");
+    } /* end switch */
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -152,21 +151,18 @@ done:
  * Return:      Success:        Message data size in bytes
  *              Failure:        0
  *
- * Programmer:  Raymond Lu
- *              August 14, 2002
- *
  *-------------------------------------------------------------------------
  */
 size_t
-H5D__layout_meta_size(const H5F_t *f, const H5O_layout_t *layout, hbool_t include_compact_data)
+H5D__layout_meta_size(const H5F_t *f, const H5O_layout_t *layout, bool include_compact_data)
 {
     size_t ret_value = 0; /* Return value */
 
     FUNC_ENTER_PACKAGE
 
     /* check args */
-    HDassert(f);
-    HDassert(layout);
+    assert(f);
+    assert(layout);
 
     ret_value = 1 + /* Version number                       */
                 1;  /* layout class type                    */
@@ -189,7 +185,7 @@ H5D__layout_meta_size(const H5F_t *f, const H5O_layout_t *layout, hbool_t includ
         case H5D_CHUNKED:
             if (layout->version < H5O_LAYOUT_VERSION_4) {
                 /* Number of dimensions (1 byte) */
-                HDassert(layout->u.chunk.ndims > 0 && layout->u.chunk.ndims <= H5O_LAYOUT_NDIMS);
+                assert(layout->u.chunk.ndims > 0 && layout->u.chunk.ndims <= H5O_LAYOUT_NDIMS);
                 ret_value++;
 
                 /* B-tree address */
@@ -203,11 +199,11 @@ H5D__layout_meta_size(const H5F_t *f, const H5O_layout_t *layout, hbool_t includ
                 ret_value++;
 
                 /* Number of dimensions (1 byte) */
-                HDassert(layout->u.chunk.ndims > 0 && layout->u.chunk.ndims <= H5O_LAYOUT_NDIMS);
+                assert(layout->u.chunk.ndims > 0 && layout->u.chunk.ndims <= H5O_LAYOUT_NDIMS);
                 ret_value++;
 
                 /* Encoded # of bytes for each chunk dimension */
-                HDassert(layout->u.chunk.enc_bytes_per_dim > 0 && layout->u.chunk.enc_bytes_per_dim <= 8);
+                assert(layout->u.chunk.enc_bytes_per_dim > 0 && layout->u.chunk.enc_bytes_per_dim <= 8);
                 ret_value++;
 
                 /* Dimension sizes */
@@ -219,7 +215,7 @@ H5D__layout_meta_size(const H5F_t *f, const H5O_layout_t *layout, hbool_t includ
                 switch (layout->u.chunk.idx_type) {
                     case H5D_CHUNK_IDX_BTREE:
                         HGOTO_ERROR(H5E_OHDR, H5E_BADVALUE, 0,
-                                    "v1 B-tree index type found for layout message >v3")
+                                    "v1 B-tree index type found for layout message >v3");
 
                     case H5D_CHUNK_IDX_NONE:
                         /* nothing */
@@ -250,7 +246,7 @@ H5D__layout_meta_size(const H5F_t *f, const H5O_layout_t *layout, hbool_t includ
 
                     case H5D_CHUNK_IDX_NTYPES:
                     default:
-                        HGOTO_ERROR(H5E_OHDR, H5E_CANTENCODE, 0, "Invalid chunk index type")
+                        HGOTO_ERROR(H5E_OHDR, H5E_CANTENCODE, 0, "Invalid chunk index type");
                 } /* end switch */
 
                 /* Chunk index address */
@@ -266,7 +262,7 @@ H5D__layout_meta_size(const H5F_t *f, const H5O_layout_t *layout, hbool_t includ
         case H5D_LAYOUT_ERROR:
         case H5D_NLAYOUTS:
         default:
-            HGOTO_ERROR(H5E_OHDR, H5E_CANTENCODE, 0, "Invalid layout class")
+            HGOTO_ERROR(H5E_OHDR, H5E_CANTENCODE, 0, "Invalid layout class");
     } /* end switch */
 
 done:
@@ -280,9 +276,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Vailin Choi; December 2017
- *
- *-------------------------------------------------------------------------
  */
 herr_t
 H5D__layout_set_version(H5F_t *f, H5O_layout_t *layout)
@@ -293,15 +286,15 @@ H5D__layout_set_version(H5F_t *f, H5O_layout_t *layout)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
-    HDassert(layout);
-    HDassert(f);
+    assert(layout);
+    assert(f);
 
     /* Upgrade to the version indicated by the file's low bound if higher */
     version = MAX(layout->version, H5O_layout_ver_bounds[H5F_LOW_BOUND(f)]);
 
     /* Version bounds check */
     if (version > H5O_layout_ver_bounds[H5F_HIGH_BOUND(f)])
-        HGOTO_ERROR(H5E_DATASET, H5E_BADRANGE, FAIL, "layout version out of bounds")
+        HGOTO_ERROR(H5E_DATASET, H5E_BADRANGE, FAIL, "layout version out of bounds");
 
     /* Set the message version */
     layout->version = version;
@@ -317,9 +310,6 @@ done:
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *              Thursday, January 15, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -330,9 +320,9 @@ H5D__layout_set_latest_indexing(H5O_layout_t *layout, const H5S_t *space, const
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(layout);
-    HDassert(space);
-    HDassert(dcpl_cache);
+    assert(layout);
+    assert(space);
+    assert(dcpl_cache);
 
     /* The indexing methods only apply to chunked datasets (currently) */
     if (layout->type == H5D_CHUNKED) {
@@ -341,7 +331,7 @@ H5D__layout_set_latest_indexing(H5O_layout_t *layout, const H5S_t *space, const
 
         /* Query the dimensionality of the dataspace */
         if ((sndims = H5S_GET_EXTENT_NDIMS(space)) < 0)
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "invalid dataspace rank")
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "invalid dataspace rank");
         ndims = (unsigned)sndims;
 
         /* Avoid scalar/null dataspace */
@@ -349,19 +339,19 @@ H5D__layout_set_latest_indexing(H5O_layout_t *layout, const H5S_t *space, const
             hsize_t  max_dims[H5O_LAYOUT_NDIMS]; /* Maximum dimension sizes */
             hsize_t  cur_dims[H5O_LAYOUT_NDIMS]; /* Current dimension sizes */
             unsigned unlim_count = 0;            /* Count of unlimited max. dimensions */
-            hbool_t  single      = TRUE;         /* Fulfill single chunk indexing */
+            bool     single      = true;         /* Fulfill single chunk indexing */
             unsigned u;                          /* Local index variable */
 
             /* Query the dataspace's dimensions */
             if (H5S_get_simple_extent_dims(space, cur_dims, max_dims) < 0)
-                HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't get dataspace max. dimensions")
+                HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't get dataspace max. dimensions");
 
             /* Spin through the max. dimensions, looking for unlimited dimensions */
             for (u = 0; u < ndims; u++) {
                 if (max_dims[u] == H5S_UNLIMITED)
                     unlim_count++;
                 if (cur_dims[u] != max_dims[u] || cur_dims[u] != layout->u.chunk.dim[u])
-                    single = FALSE;
+                    single = false;
             } /* end for */
 
             /* Chunked datasets with unlimited dimension(s) */
@@ -441,9 +431,6 @@ done:
  * Return:      Success:    SUCCEED
  *              Failure:    FAIL
  *
- * Programmer:  Quincey Koziol
- *              Monday, July 27, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -452,15 +439,15 @@ H5D__layout_oh_create(H5F_t *file, H5O_t *oh, H5D_t *dset, hid_t dapl_id)
     H5O_layout_t     *layout;                /* Dataset's layout information */
     const H5O_fill_t *fill_prop;             /* Pointer to dataset's fill value information */
     unsigned          layout_mesg_flags;     /* Flags for inserting layout message */
-    hbool_t           layout_init = FALSE;   /* Flag to indicate that chunk information was initialized */
+    bool              layout_init = false;   /* Flag to indicate that chunk information was initialized */
     herr_t            ret_value   = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE_TAG(dset->oloc.addr)
 
     /* Sanity checking */
-    HDassert(file);
-    HDassert(oh);
-    HDassert(dset);
+    assert(file);
+    assert(oh);
+    assert(dset);
 
     /* Set some local variables, for convenience */
     layout    = &dset->shared->layout;
@@ -473,28 +460,23 @@ H5D__layout_oh_create(H5F_t *file, H5O_t *oh, H5D_t *dset, hid_t dapl_id)
         pline = &dset->shared->dcpl_cache.pline;
         if (pline->nused > 0 &&
             H5O_msg_append_oh(file, oh, H5O_PLINE_ID, H5O_MSG_FLAG_CONSTANT, 0, pline) < 0)
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to update filter header message")
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to update filter header message");
     } /* end if */
 
     /* Initialize the layout information for the new dataset */
     if (dset->shared->layout.ops->init && (dset->shared->layout.ops->init)(file, dset, dapl_id) < 0)
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to initialize layout information")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to initialize layout information");
 
     /* Indicate that the layout information was initialized */
-    layout_init = TRUE;
+    layout_init = true;
 
     /*
      * Allocate storage if space allocate time is early; otherwise delay
      * allocation until later.
      */
-    if (fill_prop->alloc_time == H5D_ALLOC_TIME_EARLY) {
-        H5D_io_info_t io_info;
-
-        io_info.dset = dset;
-
-        if (H5D__alloc_storage(&io_info, H5D_ALLOC_CREATE, FALSE, NULL) < 0)
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to initialize storage")
-    }
+    if (fill_prop->alloc_time == H5D_ALLOC_TIME_EARLY)
+        if (H5D__alloc_storage(dset, H5D_ALLOC_CREATE, false, NULL) < 0)
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to initialize storage");
 
     /* Update external storage message, if it's used */
     if (dset->shared->dcpl_cache.efl.nused > 0) {
@@ -506,28 +488,27 @@ H5D__layout_oh_create(H5F_t *file, H5O_t *oh, H5D_t *dset, hid_t dapl_id)
 
         /* Determine size of heap needed to stored the file names */
         for (u = 0; u < efl->nused; ++u)
-            heap_size += H5HL_ALIGN(HDstrlen(efl->slot[u].name) + 1);
+            heap_size += H5HL_ALIGN(strlen(efl->slot[u].name) + 1);
 
         /* Create the heap for the EFL file names */
         if (H5HL_create(file, heap_size, &efl->heap_addr /*out*/) < 0)
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to create EFL file name heap")
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to create EFL file name heap");
 
         /* Pin the heap down in memory */
         if (NULL == (heap = H5HL_protect(file, efl->heap_addr, H5AC__NO_FLAGS_SET)))
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTPROTECT, FAIL, "unable to protect EFL file name heap")
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTPROTECT, FAIL, "unable to protect EFL file name heap");
 
         /* Insert "empty" name first */
         if (H5HL_insert(file, heap, (size_t)1, "", &name_offset) < 0) {
             H5HL_unprotect(heap);
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTINSERT, FAIL, "unable to insert file name into heap")
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTINSERT, FAIL, "unable to insert file name into heap");
         }
 
         for (u = 0; u < efl->nused; ++u) {
             /* Insert file name into heap */
-            if (H5HL_insert(file, heap, HDstrlen(efl->slot[u].name) + 1, efl->slot[u].name, &name_offset) <
-                0) {
+            if (H5HL_insert(file, heap, strlen(efl->slot[u].name) + 1, efl->slot[u].name, &name_offset) < 0) {
                 H5HL_unprotect(heap);
-                HGOTO_ERROR(H5E_DATASET, H5E_CANTINSERT, FAIL, "unable to insert file name into heap")
+                HGOTO_ERROR(H5E_DATASET, H5E_CANTINSERT, FAIL, "unable to insert file name into heap");
             }
 
             /* Store EFL file name offset */
@@ -536,12 +517,12 @@ H5D__layout_oh_create(H5F_t *file, H5O_t *oh, H5D_t *dset, hid_t dapl_id)
 
         /* Release the heap */
         if (H5HL_unprotect(heap) < 0)
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTUNPROTECT, FAIL, "unable to unprotect EFL file name heap")
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTUNPROTECT, FAIL, "unable to unprotect EFL file name heap");
         heap = NULL;
 
         /* Insert EFL message into dataset object header */
         if (H5O_msg_append_oh(file, oh, H5O_EFL_ID, H5O_MSG_FLAG_CONSTANT, 0, efl) < 0)
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to update external file list message")
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to update external file list message");
     } /* end if */
 
     /* Create layout message */
@@ -557,11 +538,11 @@ H5D__layout_oh_create(H5F_t *file, H5O_t *oh, H5D_t *dset, hid_t dapl_id)
     /* Store VDS info in global heap */
     if (H5D_VIRTUAL == layout->type)
         if (H5D__virtual_store_layout(file, layout) < 0)
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTSET, FAIL, "unable to store VDS info")
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTSET, FAIL, "unable to store VDS info");
 
     /* Create layout message */
     if (H5O_msg_append_oh(file, oh, H5O_LAYOUT_ID, layout_mesg_flags, 0, layout) < 0)
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to update layout")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to update layout");
 
 done:
     /* Error cleanup */
@@ -569,7 +550,7 @@ done:
         if (layout_init)
             /* Destroy any cached layout information for the dataset */
             if (dset->shared->layout.ops->dest && (dset->shared->layout.ops->dest)(dset) < 0)
-                HDONE_ERROR(H5E_DATASET, H5E_CANTRELEASE, FAIL, "unable to destroy layout info")
+                HDONE_ERROR(H5E_DATASET, H5E_CANTRELEASE, FAIL, "unable to destroy layout info");
 
     FUNC_LEAVE_NOAPI_TAG(ret_value)
 } /* end H5D__layout_oh_create() */
@@ -582,38 +563,34 @@ done:
  * Return:      Success:    SUCCEED
  *              Failure:    FAIL
  *
- * Programmer:  Quincey Koziol
- *              Monday, July 27, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
 H5D__layout_oh_read(H5D_t *dataset, hid_t dapl_id, H5P_genplist_t *plist)
 {
-    htri_t  msg_exists;              /* Whether a particular type of message exists */
-    hbool_t pline_copied  = FALSE;   /* Flag to indicate that dcpl_cache.pline's message was copied */
-    hbool_t layout_copied = FALSE;   /* Flag to indicate that layout message was copied */
-    hbool_t efl_copied    = FALSE;   /* Flag to indicate that the EFL message was copied */
-    herr_t  ret_value     = SUCCEED; /* Return value */
+    htri_t msg_exists;              /* Whether a particular type of message exists */
+    bool   pline_copied  = false;   /* Flag to indicate that dcpl_cache.pline's message was copied */
+    bool   layout_copied = false;   /* Flag to indicate that layout message was copied */
+    bool   efl_copied    = false;   /* Flag to indicate that the EFL message was copied */
+    herr_t ret_value     = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE
 
     /* Sanity checking */
-    HDassert(dataset);
-    HDassert(plist);
+    assert(dataset);
+    assert(plist);
 
     /* Get the optional filters message */
     if ((msg_exists = H5O_msg_exists(&(dataset->oloc), H5O_PLINE_ID)) < 0)
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't check if message exists")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't check if message exists");
     if (msg_exists) {
         /* Retrieve the I/O pipeline message */
         if (NULL == H5O_msg_read(&(dataset->oloc), H5O_PLINE_ID, &dataset->shared->dcpl_cache.pline))
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't retrieve message")
-        pline_copied = TRUE;
-
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't retrieve message");
+        pline_copied = true;
         /* Set the I/O pipeline info in the property list */
         if (H5P_set(plist, H5O_CRT_PIPELINE_NAME, &dataset->shared->dcpl_cache.pline) < 0)
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTSET, FAIL, "can't set pipeline")
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTSET, FAIL, "can't set pipeline");
     } /* end if */
 
     /*
@@ -623,33 +600,33 @@ H5D__layout_oh_read(H5D_t *dataset, hid_t dapl_id, H5P_genplist_t *plist)
      * them.
      */
     if (NULL == H5O_msg_read(&(dataset->oloc), H5O_LAYOUT_ID, &(dataset->shared->layout)))
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to read data layout message")
-    layout_copied = TRUE;
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to read data layout message");
+    layout_copied = true;
 
     /* Check for external file list message (which might not exist) */
     if ((msg_exists = H5O_msg_exists(&(dataset->oloc), H5O_EFL_ID)) < 0)
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't check if message exists")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't check if message exists");
     if (msg_exists) {
-        /* Retrieve the EFL message */
+        /* Retrieve the EFL  message */
         if (NULL == H5O_msg_read(&(dataset->oloc), H5O_EFL_ID, &dataset->shared->dcpl_cache.efl))
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't retrieve message")
-        efl_copied = TRUE;
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't retrieve message");
+        efl_copied = true;
 
         /* Set the EFL info in the property list */
         if (H5P_set(plist, H5D_CRT_EXT_FILE_LIST_NAME, &dataset->shared->dcpl_cache.efl) < 0)
-            HGOTO_ERROR(H5E_DATASET, H5E_CANTSET, FAIL, "can't set external file list")
+            HGOTO_ERROR(H5E_DATASET, H5E_CANTSET, FAIL, "can't set external file list");
 
         /* Set the dataset's I/O operations */
         dataset->shared->layout.ops = H5D_LOPS_EFL;
     } /* end if */
 
     /* Sanity check that the layout operations are set up */
-    HDassert(dataset->shared->layout.ops);
+    assert(dataset->shared->layout.ops);
 
     /* Initialize the layout information for the dataset */
     if (dataset->shared->layout.ops->init &&
         (dataset->shared->layout.ops->init)(dataset->oloc.file, dataset, dapl_id) < 0)
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to initialize layout information")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to initialize layout information");
 
     /* Adjust chunk dimensions to omit datatype size (in last dimension) for creation property */
     if (H5D_CHUNKED == dataset->shared->layout.type)
@@ -657,24 +634,24 @@ H5D__layout_oh_read(H5D_t *dataset, hid_t dapl_id, H5P_genplist_t *plist)
 
     /* Copy layout to the DCPL */
     if (H5P_set(plist, H5D_CRT_LAYOUT_NAME, &dataset->shared->layout) < 0)
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTSET, FAIL, "can't set layout")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTSET, FAIL, "can't set layout");
 
     /* Set chunk sizes */
     if (H5D_CHUNKED == dataset->shared->layout.type)
         if (H5D__chunk_set_sizes(dataset) < 0)
-            HGOTO_ERROR(H5E_DATASET, H5E_BADVALUE, FAIL, "unable to set chunk sizes")
+            HGOTO_ERROR(H5E_DATASET, H5E_BADVALUE, FAIL, "unable to set chunk sizes");
 
 done:
     if (ret_value < 0) {
         if (pline_copied)
             if (H5O_msg_reset(H5O_PLINE_ID, &dataset->shared->dcpl_cache.pline) < 0)
-                HDONE_ERROR(H5E_DATASET, H5E_CANTRESET, FAIL, "unable to reset pipeline info")
+                HDONE_ERROR(H5E_DATASET, H5E_CANTRESET, FAIL, "unable to reset pipeline info");
         if (layout_copied)
             if (H5O_msg_reset(H5O_LAYOUT_ID, &dataset->shared->layout) < 0)
-                HDONE_ERROR(H5E_DATASET, H5E_CANTRESET, FAIL, "unable to reset layout info")
+                HDONE_ERROR(H5E_DATASET, H5E_CANTRESET, FAIL, "unable to reset layout info");
         if (efl_copied)
             if (H5O_msg_reset(H5O_EFL_ID, &dataset->shared->dcpl_cache.efl) < 0)
-                HDONE_ERROR(H5E_DATASET, H5E_CANTRESET, FAIL, "unable to reset efl message")
+                HDONE_ERROR(H5E_DATASET, H5E_CANTRESET, FAIL, "unable to reset efl message");
     }
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5D__layout_oh_read() */
@@ -687,9 +664,6 @@ done:
  * Return:      Success:    SUCCEED
  *              Failure:    FAIL
  *
- * Programmer:  Quincey Koziol
- *              Monday, July 27, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -701,17 +675,17 @@ H5D__layout_oh_write(const H5D_t *dataset, H5O_t *oh, unsigned update_flags)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checking */
-    HDassert(dataset);
-    HDassert(oh);
+    assert(dataset);
+    assert(oh);
 
     /* Check if the layout message has been added to the dataset's header */
     if ((msg_exists = H5O_msg_exists_oh(oh, H5O_LAYOUT_ID)) < 0)
-        HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "unable to check if layout message exists")
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "unable to check if layout message exists");
     if (msg_exists) {
         /* Write the layout message to the dataset's header */
         if (H5O_msg_write_oh(dataset->oloc.file, oh, H5O_LAYOUT_ID, 0, update_flags,
                              &dataset->shared->layout) < 0)
-            HGOTO_ERROR(H5E_DATASET, H5E_WRITEERROR, FAIL, "unable to update layout message")
+            HGOTO_ERROR(H5E_DATASET, H5E_WRITEERROR, FAIL, "unable to update layout message");
     } /* end if */
 
 done:
